# NOT RUN {
df <- data.frame(id = seq(1:20),
n_tested = rpois(20, 5),
test_Se = 0.3,
dp = 0.05)
## Calculate the herd level sensitivity for each of these herds given
## the assumption that the herds have an infinite size.
hse_infinite(df$id,
df$n_tested,
df$test_Se,
df$dp)
# }
Run the code above in your browser using DataLab